@@ -1,6 +1,7 @@
 from coleo import Argument as Arg, default, tooled
 
 from ..io import PapersFile, ResearchersFile
+from ..papers import Paper
 from .interactive import InteractiveCommands, default_commands
 from .searchutils import search
 
@@ -50,6 +51,12 @@ def command_collect():
     # Prompt for papers even if they were excluded from the collection
     show_excluded: Arg & bool = default(False)
 
+    # Display long form for each paper
+    long: Arg & bool = default(False)
+
+    # Update existing papers with new information
+    update: Arg & bool = default(False)
+
     # Include all papers from the collection
     # [options: --yes]
     yes_: Arg & bool = default(False)
@@ -68,11 +75,16 @@ def command_collect():
 
     for paper in papers:
         if paper in collection:
+            if update:
+                collection.add(paper)
             continue
         if not show_excluded and collection.excludes(paper):
             continue
         instruction = search_commands.process_paper(
-            paper, collection=collection, command=command,
+            paper,
+            collection=collection,
+            command=command,
+            formatter=Paper.format_term_long if long else Paper.format_term,
         )
         if instruction is False:
             break
