@@ -71,6 +71,7 @@ def _find_ids(rsch):
             q, ",".join(Papers.fields), orderby="D:desc", count=1000
         )
         papers = Papers({p["Id"]: p for p in papers}, None)
+        dunno = set()
         for p in papers:
             aid = [
                 auth.aid for auth in p.authors if auth.data["AuN"] == auth_name
@@ -78,7 +79,7 @@ def _find_ids(rsch):
             if not aid:
                 continue
             aid = aid[0]
-            if aid in noids or aid in ids:
+            if aid in noids or aid in ids or aid in dunno:
                 continue
             print("=" * 80)
             p.format_term()
@@ -86,7 +87,7 @@ def _find_ids(rsch):
             exit = False
             while True:
                 answer = input(
-                    f"Is this a paper by the author? (authid={aid}) [y]es/[n]o/[s]kip/[l]ong/[q]uit "
+                    f"Is this a paper by the author? (authid={aid}) [y]es/[n]o/[m]ore/[s]kip/[l]ong/[q]uit "
                 )
                 if answer == "y":
                     ids.append(aid)
@@ -94,7 +95,10 @@ def _find_ids(rsch):
                 elif answer == "n":
                     noids.append(aid)
                     break
+                elif answer == "m":
+                    break
                 elif answer == "s":
+                    dunno.add(aid)
                     break
                 elif answer == "l":
                     p.format_term_long()
@@ -122,38 +126,46 @@ def command_researcher():
     author: Arg & str
     author = " ".join(author)
 
+    # Find IDs for the researcher
+    find_ids: Arg & bool = default(False)
+
     data = researchers.get(author)
 
     original = deepcopy(data.data)
 
-    while True:
-        print(T.bold("Current data about"), T.bold_cyan(author))
-        print(json.dumps(data.data, indent=2))
-        print()
+    if find_ids:
+        _find_ids(data)
+        researchers.save()
 
-        print(T.bold("What do you want to do?"))
-        print(T.bold_yellow("(1)"), "Find ids")
-        print(T.bold_yellow("(2)"), "Set a property")
-        print(T.bold_yellow("(3)"), "Add a role")
-        print(T.bold_yellow("(*)"), "Quit (any other key)")
-        task = input(T.bold("> "))
-
-        if task == "1":
+    else:
+        while True:
+            print(T.bold("Current data about"), T.bold_cyan(author))
+            print(json.dumps(data.data, indent=2))
             print()
-            _find_ids(data)
 
-        elif task == "2":
-            print()
-            _set_property(data)
+            print(T.bold("What do you want to do?"))
+            print(T.bold_yellow("(1)"), "Find ids")
+            print(T.bold_yellow("(2)"), "Set a property")
+            print(T.bold_yellow("(3)"), "Add a role")
+            print(T.bold_yellow("(*)"), "Quit (any other key)")
+            task = input(T.bold("> "))
 
-        elif task == "3":
-            print()
-            _add_role(data)
+            if task == "1":
+                print()
+                _find_ids(data)
 
-        else:
-            break
+            elif task == "2":
+                print()
+                _set_property(data)
 
-    if data.data != original:
-        save = input(T.bold("Save changes? [y]/n ")).strip()
-        if save == "y" or save == "":
-            researchers.save()
+            elif task == "3":
+                print()
+                _add_role(data)
+
+            else:
+                break
+
+        if data.data != original:
+            save = input(T.bold("Save changes? [y]/n ")).strip()
+            if save == "y" or save == "":
+                researchers.save()
