@@ -1,6 +1,7 @@
 from coleo import Argument as Arg, default, tooled
 
 from ..io import PapersFile, ResearchersFile
+from ..papers import Paper
 from .interactive import InteractiveCommands, default_commands
 from .searchutils import search
 
@@ -62,13 +63,19 @@ def command_search():
     # Command to run on every paper
     command: Arg = default(None)
 
+    # Display long form for each paper
+    long: Arg & bool = default(False)
+
     papers = search(collection=collection, researchers=researchers)
 
     sch = search_commands if collection is None else search_commands_with_coll
 
     for paper in papers:
         instruction = sch.process_paper(
-            paper, command=command, collection=collection
+            paper,
+            command=command,
+            collection=collection,
+            formatter=Paper.format_term_long if long else Paper.format_term,
         )
         if instruction is False:
             break
