@@ -109,12 +109,21 @@ class QueryManager:
         return entity
 
     def _q_author(self, author):
-        if isinstance(author, int):
+        if isinstance(author, list):
+            if len(author) == 1:
+                return self._q_author(author[0])
+            else:
+                results = ",".join(self._q_author(a) for a in author)
+                return f"Or({results})"
+        elif isinstance(author, int):
             return f"Composite(AA.AuId={author})"
         else:
             author = author.lower()
             return f"Composite(AA.AuN='{author}')"
 
+    def _q_paper_id(self, paper_id):
+        return f"Id={paper_id}"
+
     def _q_title(self, title):
         title = title.lower()
         title = re.split(r"\W+", title)
